local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local _

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["auto_shot"] = {
	ID = 75--[[Auto Shot]],
	EnemyTargetNeeded = true,
	NotIfActive = true,
	Check = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Green", "Pink")
		return not s.Shooting()
	end,
	NoGCD = true,
}


a.spells["arcane_torrent,if=focus.deficit>=30"] = {
	ID = 80483--[[Arcane Torrent]],
	NoRangeCheck = true,
	Check = function(z)
		if x.Boss then
			z.FlashColor = "Yellow"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.ShouldTemporaryBuff and x.InCombat and not x.Stop  and (x.MaxFocus - x.Focus) >= 30
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	NoGCD = true,
}

a.spells["berserking"] = {
	ID = 26297--[[Berserking]],
	NoRangeCheck = true,
	Check = function(z)
		if x.Boss then
			z.FlashColor = "Yellow"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.ShouldTemporaryBuff and x.InCombat and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	NoGCD = true,
}

a.spells["blood_fury"] = {
	ID = 20572--[[Blood Fury]],
	NoRangeCheck = true,
	Check = function(z)
		if x.Boss then
			z.FlashColor = "Yellow"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.ShouldTemporaryBuff and x.InCombat and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	NoGCD = true,
}

a.spells["Pet Attack"] = {
	Override = function(z)
		if x.PetAlive and x.Enemy and not UnitGUID("pettarget") then
			s.FlashPet(PET_ACTION_ATTACK, "Green")
		elseif x.PetAlive and x.Enemy and not s.SameTargetAsPet() then
			s.FlashPet(PET_ACTION_ATTACK, "Pink")
		end
	end,
	NoGCD = true,
}

a.spells["Pet Assist"] = {
	Override = function(z)
		if x.ActiveEnemy and x.PetAlive and not x.PetActiveEnemy and not a.PetAssistActive() then
			s.FlashPet(PET_MODE_ASSIST, "Pink")
		end
	end,
	NoGCD = true,
}

a.spells["Aspect of the Hawk"] = {
	Type = "form",
	ID = 13165--[[Aspect of the Hawk]],
	Buff = {
		13165--[[Aspect of the Hawk]],
		109260--[[Aspect of the Iron Hawk]],
	},
	BuffUnit = "player",
	NotWhileMoving = true,
	NoGCD = true,
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldTemporaryBuff and (not s.Moving("player") or s.InCombat())
	end,
	FlashID = {
		13165--[[Aspect of the Hawk]],
		109260--[[Aspect of the Iron Hawk]],
	},
}


a.spells["Aspect of the Cheetah while moving"] = {
	Type = "form",
	ID = 5118--[[Aspect of the Cheetah]],
	MyBuff = 5118--[[Aspect of the Cheetah]],
	BuffUnit = "player",
	NotWhileMoving = false,
	NoGCD = true,
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff and s.Moving("player") and not s.InCombat()
	end,
}

a.spells["explosive_trap,if=active_enemies>2"] = {
	ID = 13813--[[Explosive Trap]],
	Check = function(z)
		return x.ActiveEnemy
	end,
	Run = function(z)
		if x.ActiveEnemies > 2 then
			z.Continue = false
			z.FlashColor = "White"
		else
			z.Continue = true
			z.FlashColor = "Blue"
		end
	end,
	FlashID = {
		13813--[[Explosive Trap]],
		82939--[[Explosive Trap]],
	},
	NoRangeCheck = true,
}

a.spells["focus_fire,five_stacks=1"] = {
	ID = 82692--[[Focus Fire]],
	Check = function(z)
		return x.InCombat and x.PetAlive and s.BuffStack(19615--[[Frenzy]], "pet", nil, false, false, true) >= 5
	end,
}

a.spells["focus_fire,five_stacks=1,if=!ticking&!buff.beast_within.up"] = {
	ID = 82692--[[Focus Fire]],
	Buff = 82692--[[Focus Fire]],
	BuffUnit = "player",
	ConsumeBuff = 19615--[[Frenzy]],
	ConsumeStack = 5,
	ConsumeStackTaken = 5,
	ConsumeBuffUnit = "pet",
	Check = function(z)
		return x.InCombat and x.PetAlive and s.BuffDuration(34471--[[The Beast Within]], "player") <= x.GCD
	end,
}

a.spells["chimaera_shot"] = {
	ID = 53209--[[Chimera Shot]],
	EnemyTargetNeeded = true,
}

a.spells["bestial_wrath,if=focus>60&!buff.bestial_wrath.up"] = {
	ID = 19574--[[Bestial Wrath]],
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and x.InCombat and x.Focus > 60 and x.BuffBestialWrathRemains <= x.Lag
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["multishot,if=active_enemies>5|(active_enemies>1&pet.cat.buff.beast_cleave.down)"] = {
	ID = 2643--[[Multi-Shot]],
	Run = function(z)
		if x.ActiveEnemies > 5 or (x.ActiveEnemies > 1 and s.BuffDuration(118455--[[Beast Cleave]], "pet") <= x.GCD) then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Blue"
			z.Continue = true
		end
	end,
	EnemyTargetNeeded = true,
}

a.spells["multi_shot,if=buff.thrill_of_the_hunt.react&dot.serpent_sting.remains<2"] = {
	ID = 2643--[[Multi-Shot]],
	MyDebuff = 1978--[[Serpent Sting]],
	EarlyRefresh = 2,
	ConsumeBuff = 34720--[[Thrill of the Hunt]],
	ConsumeBuffUnit = "player",
	ConsumeStackTaken = 1,
	EnemyTargetNeeded = true,
}

a.spells["multi_shot,if=active_enemies>5"] = {
	ID = 2643--[[Multi-Shot]],
	Run = function(z)
		if x.ActiveEnemies > 5 then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Blue"
			z.Continue = true
		end
	end,
	EnemyTargetNeeded = true,
}

a.spells["multi_shot,if=active_enemies>3"] = {
	ID = 2643--[[Multi-Shot]],
	Run = function(z)
		if x.ActiveEnemies > 3 then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Blue"
			z.Continue = true
		end
	end,
	EnemyTargetNeeded = true,
}

a.spells["cobra_shot"] = {
	ID = 77767--[[Cobra Shot]],
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["cobra_shot,if=buff.pre_steady_focus.up&(14+cast_regen)<=focus.deficit"] = {
	ID = 77767--[[Cobra Shot]],
	Check = function(z)
		return a.PreSteadyFocus() and (s.CastTime(77767--[[Cobra Shot]]) * x.FocusPerSecond + 14) <= x.FocusDeficit
	end,
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["cobra_shot,if=active_enemies>5"] = {
	ID = 77767--[[Cobra Shot]],
	Check = function(z)
		return not x.TalentFocusingShotEnabled and x.ActiveEnemies > 5
	end,
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["steady_shot"] = {
	ID = 56641--[[Steady Shot]],
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["steady_shot,if=focus.deficit*cast_time%(14+cast_regen)>cooldown.rapid_fire.remains"] = {
	ID = 56641--[[Steady Shot]],
	Check = function(z)
		local cast_time = s.CastTime(56641--[[Steady Shot]])
		return not x.TalentFocusingShotEnabled and x.FocusDeficit * cast_time / (14 + cast_time * x.FocusPerSecond) > x.CooldownRapidFireRemains
	end,
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["steady_shot,if=buff.pre_steady_focus.up&(14+cast_regen+action.aimed_shot.cast_regen)<=focus.deficit"] = {
	ID = 56641--[[Steady Shot]],
	Check = function(z)
		local cast_time = s.CastTime(56641--[[Steady Shot]])
		return not x.TalentFocusingShotEnabled and a.PreSteadyFocus() and (14 + s.CastTime(56641--[[Steady Shot]]) * x.FocusPerSecond + x.AimedShotCastRegen) <= x.FocusDeficit
	end,
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["focusing_shot,if=focus<50"] = {
	ID = 152245--[[Focusing Shot]],
	Check = function(z)
		return x.Focus < 50 and x.TalentFocusingShotEnabled
	end,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["focusing_shot,if=focus.deficit*cast_time%(50+cast_regen)>cooldown.rapid_fire.remains&focus<100"] = {
	ID = 152245--[[Focusing Shot]],
	Check = function(z)
		local cast_time = s.CastTime(152245--[[Focusing Shot]])
		return x.TalentFocusingShotEnabled and x.FocusDeficit * cast_time / (50 + cast_time * x.FocusPerSecond) > x.CooldownRapidFireRemains and x.Focus < 100
	end,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["focusing_shot,if=50+cast_regen-10<focus.deficit"] = {
	ID = 152245--[[Focusing Shot]],
	Check = function(z)
		local cast_time = s.CastTime(152245--[[Focusing Shot]])
		return x.TalentFocusingShotEnabled and (50 + cast_time * x.FocusPerSecond - 10) < x.FocusDeficit
	end,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
}

a.spells["kill_shot,if=focus.time_to_max>gcd"] = {
	ID = 53351--[[Kill Shot]],
	Check = function(z)
		return x.TimeToMax > x.GCD
	end,
	EnemyTargetNeeded = true,
}

a.spells["kill_shot,if=cast_regen+action.aimed_shot.cast_regen<focus.deficit"] = {
	ID = 53351--[[Kill Shot]],
	Check = function(z)
		return x.FocusPerSecond + x.AimedShotCastRegen < x.FocusDeficit
	end,
	EnemyTargetNeeded = true,
}

a.spells["a_murder_of_crows"] = {
	ID = 131894--[[A Murder of Crows]],
	Check = function(z)
		if x.Boss then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return s.HasTalent(131894--[[A Murder of Crows]]) and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	EnemyTargetNeeded = true,
}

a.spells["fervor,if=enabled&focus<=50"] = {
	ID = 82726--[[Fervor]],
	Buff = 82726--[[Fervor]],
	BuffUnit = "player",
	Check = function(z)
		return x.ActiveEnemy and s.HasTalent(82726--[[Fervor]]) and x.CurrentFocus <= 50
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["fervor,if=enabled&!ticking&focus<=65"] = {
	ID = 82726--[[Fervor]],
	Buff = 82726--[[Fervor]],
	BuffUnit = "player",
	Check = function(z)
		return x.ActiveEnemy and s.HasTalent(82726--[[Fervor]]) and x.CurrentFocus <= 65
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["powershot,if=cast_regen<focus.deficit"] = {
	ID = 109259--[[Powershot]],
	NotWhileMoving = true,
	Check = function(z)
		return s.HasTalent(109259--[[Powershot]]) and s.CastTime(109259--[[Powershot]]) * x.FocusPerSecond < x.FocusDeficit
	end,
	EnemyTargetNeeded = true,
}

a.spells["powershot,if=active_enemies>1&cast_regen<focus.deficit"] = {
	ID = 109259--[[Powershot]],
	NotWhileMoving = true,
	Check = function(z)
		return s.HasTalent(109259--[[Powershot]]) and x.ActiveEnemies > 1 and s.CastTime(109259--[[Powershot]]) * x.FocusPerSecond < x.FocusDeficit
	end,
	EnemyTargetNeeded = true,
}

a.spells["powershot,if=focus.time_to_max>cast_time"] = {
	ID = 109259--[[Powershot]],
	NotWhileMoving = true,
	Check = function(z)
		return s.HasTalent(109259--[[Powershot]]) and x.TimeToMax > s.CastTime(109259--[[Powershot]]) + x.GCD
	end,
	EnemyTargetNeeded = true,
}

a.spells["barrage,if=active_enemies>2"] = {
	ID = 120360--[[Barrage]],
	Check = function(z)
		return s.HasTalent(120360--[[Barrage]]) and x.ActiveEnemies > 2 and x.Focus >= 60
	end,
}

a.spells["barrage,if=active_enemies>1"] = {
	ID = 120360--[[Barrage]],
	Check = function(z)
		return s.HasTalent(120360--[[Barrage]]) and x.ActiveEnemies > 1 and x.Focus >= 60
	end,
}

a.spells["barrage"] = {
	ID = 120360--[[Barrage]],
	Check = function(z)
		return s.HasTalent(120360--[[Barrage]]) and x.Focus >= 60
	end,
}

a.spells["stampede,if=buff.bloodlust.up|buff.focus_fire.up|target.time_to_die<=20"] = {
	ID = 121818--[[Stampede]],
	Check = function(z)
		if x.Boss then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.InCombat and x.TalentStampedeEnabled and (a.Hasted() or x.BuffFocusFireRemains > x.GCD or (x.Boss and x.TimeToDie <= 20)) and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	EnemyTargetNeeded = true,
}

a.spells["stampede,if=buff.rapid_fire.up|buff.bloodlust.up|target.time_to_die<=20"] = {
	ID = 121818--[[Stampede]],
	Check = function(z)
		if x.Boss then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.ActiveEnemy and (a.Hasted() or (x.Boss and x.TimeToDie <= 20)) and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	EnemyTargetNeeded = true,
}

a.spells["stampede,if=buff.rapid_fire.up|buff.bloodlust.react|target.time_to_die<=25"] = {
	ID = 121818--[[Stampede]],
	Check = function(z)
		if x.Boss then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.ActiveEnemy and (a.Hasted() or (x.Boss and x.TimeToDie <= 25)) and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	EnemyTargetNeeded = true,
}

a.spells["glaive_toss"] = {
	ID = 117050--[[Glaive Toss]],
	Check = function(z)
		return s.HasTalent(117050--[[Glaive Toss]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["glaive_toss,if=active_enemies>4"] = {
	ID = 117050--[[Glaive Toss]],
	Check = function(z)
		return s.HasTalent(117050--[[Glaive Toss]]) and x.ActiveEnemies > 4
	end,
	EnemyTargetNeeded = true,
}

a.spells["dire_beast"] = {
	ID = 120679--[[Dire Beast]],
	Check = function(z)
		return s.HasTalent(120679--[[Dire Beast]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["dire_beast,if=cast_regen+action.aimed_shot.cast_regen<focus.deficit"] = {
	ID = 120679--[[Dire Beast]],
	Check = function(z)
		return s.HasTalent(120679--[[Dire Beast]]) and (x.FocusPerSecond + x.AimedShotCastRegen) < x.FocusDeficit
	end,
	EnemyTargetNeeded = true,
}

a.spells["kill_command"] = {
	ID = 34026--[[Kill Command]],
	Check = function(z)
		return x.PetAlive and x.PetActiveEnemy and (x.Focus >= 40 or (x.BuffBestialWrathRemains > x.Lag and x.Focus >= 20))
	end,
	PetFrameNeeded = true,
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
}

a.spells["arcane_shot,if=buff.thrill_of_the_hunt.react"] = {
	ID = 3044--[[Arcane Shot]],
	ConsumeBuff = 34720--[[Thrill of the Hunt]],
	ConsumeBuffUnit = "player",
	ConsumeStackTaken = 1,
	EnemyTargetNeeded = true,
}

a.spells["arcane_shot,if=focus>=64"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return x.Focus >= 64
	end,
	EnemyTargetNeeded = true,
}

a.spells["arcane_shot,if=focus>=60|(focus>=43&(cooldown.chimera_shot.remains>=action.steady_shot.cast_time))&(!buff.rapid_fire.up&!buff.bloodlust.react)"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return x.Focus >= (75 - x.FocusPerSecond * (1 + x.GCD)) or (x.Focus >= (75 - 14 - x.FocusPerSecond * (1 + x.GCD + s.CastTime(56641--[[Steady Shot]]))) and s.SpellCooldown(53209--[[Chimera Shot]]) >= s.CastTime(56641--[[Steady Shot]]) + x.GCD + 1 and not a.Hasted())
--		return x.Focus >= 60 or (x.Focus >= 43 and s.SpellCooldown(53209--[[Chimera Shot]]) >= s.CastTime(56641--[[Steady Shot]]) + x.GCD + 1 and not a.Hasted())
	end,
	EnemyTargetNeeded = true,
}

a.spells["arcane_shot,if=(buff.thrill_of_the_hunt.react&focus>35)|buff.bestial_wrath.up"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return (s.BuffDuration(34720--[[Thrill of the Hunt]], "player", nil, false, false, true) > x.GCD and x.Focus > 35) or (x.BuffBestialWrathRemains > x.GCD and x.Focus >= 15)
	end,
	EnemyTargetNeeded = true,
}

a.spells["arcane_shot,if=focus>=61|buff.beast_within.up"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return (x.Focus >= 61 or s.BuffDuration(34471--[[The Beast Within]], "player") > x.GCD)
	end,
	EnemyTargetNeeded = true,
}

a.spells["arcane_shot,if=focus>=67"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return x.Focus >= 67
	end,
	EnemyTargetNeeded = true,
}

a.spells["rapid_fire"] = {
	ID = 3045--[[Rapid Fire]],
	Check = function(z)
		if x.Boss then
			z.FlashColor = "Yellow"
			z.Continue = false
		else
			z.FlashColor = "Pink"
			z.Continue = true
		end
		return x.ShouldTemporaryBuff and x.ActiveEnemy and not x.Stop
	end,
	RunLast = function(z)
		x.Stop = true
	end,
	NoGCD = true,
}

a.spells["aimed_shot"] = {
	ID = 19434--[[Aimed Shot]],
	Check = function(z)
		return x.Focus >= 50 or (s.BuffDuration(34720--[[Thrill of the Hunt]], "player", nil, false, false, true) > x.GCD and x.Focus >= 30)
	end,
	EnemyTargetNeeded = true,
	NotWhileMoving = false,
}

a.spells["aimed_shot,if=talent.focusing_shot.enabled"] = {
	ID = 19434--[[Aimed Shot]],
	Check = function(z)
		return x.TalentFocusingShotEnabled
	end,
	EnemyTargetNeeded = true,
	NotWhileMoving = false,
}

a.spells["aimed_shot,if=focus+cast_regen>=85"] = {
	ID = 19434--[[Aimed Shot]],
	Check = function(z)
		return (x.Focus + x.AimedShotCastRegen) >= 85
	end,
	NotWhileMoving = false,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	NoRangeCheck = true,
}

a.spells["aimed_shot,if=buff.thrill_of_the_hunt.react&focus+cast_regen>=65"] = {
	ID = 19434--[[Aimed Shot]],
	Check = function(z)
		return s.BuffDuration(34720--[[Thrill of the Hunt]], "player", nil, false, false, true) > x.GCD and (x.Focus + x.AimedShotCastRegen) >= 65
	end,
	EnemyTargetNeeded = true,
	NotWhileMoving = false,
}

a.spells["Call Pet"] = {
	ID = 9--[[Call Pet]],
	Override = function(z)
		if not x.PetAlive and x.ShouldPermanentBuff then
			s.Flash({
				9--[[Call Pet]],
				883--[[Call Pet 1]],
				83242--[[Call Pet 2]],
				83243--[[Call Pet 3]],
				83244--[[Call Pet 4]],
				83245--[[Call Pet 5]],
				982--[[Revive Pet]]})
		end
	end,
}

a.spells["Mend Pet"] = {
	ID = 136--[[Mend Pet]],
	Buff = 136--[[Mend Pet]],
	BuffUnit = "pet",
	EarlyRefresh = 1,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.PetAlive and (s.HealthPercent("pet") < 80 or (s.HasGlyph(19573--[[Glyph of Mend Pet]]) and s.Debuff(nil, "pet", nil, nil, 1)))
	end,
	FlashColor = "Red",
}

a.spells["explosive_shot,if=buff.lock_and_load.react"] = {
	ID = 53301--[[Explosive Shot]],
	RequireBuff = 56453--[[Lock and Load]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = true,
}

a.spells["explosive_shot,if=cooldown_react"] = {
	ID = 53301--[[Explosive Shot]],
	EnemyTargetNeeded = true,
}

a.spells["black_arrow,if=!ticking&target.time_to_die>=8"] = {
	ID = 3674--[[Black Arrow]],
	MyDebuff = 3674--[[Black Arrow]],
	Check = function(z)
		return x.TimeToDie >= 8
	end,
	EnemyTargetNeeded = true,
}

a.spells["potion,name=draenic_agility"] = {
	Type = "item",
	ID = 109217--[[Draenic Agility Potion]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target")
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["potion,name=draenic_agility,if=!talent.stampede.enabled&buff.bestial_wrath.up|target.time_to_die<=20"] = {
	Type = "item",
	ID = 109217--[[Draenic Agility Potion]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and (not x.TalentStampedeEnabled and x.BuffBestialWrathRemains > x.Lag or x.TimeToDie <= 20)
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["potion,name=draenic_agility,if=talent.stampede.enabled&cooldown.stampede.remains<1&(buff.bloodlust.up|buff.focus_fire.up)|target.time_to_die<=20"] = {
	Type = "item",
	ID = 109217--[[Draenic Agility Potion]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and (x.TalentStampedeEnabled and s.SpellCooldown(121818--[[Stampede]]) < (1 + x.Lag) and (a.Bloodlust() or x.BuffFocusFireRemains > x.Lag) or x.TimeToDie <= 20)
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["potion,name=draenic_agility,if=((buff.rapid_fire.up|buff.bloodlust.up)&(!talent.stampede.enabled|cooldown.stampede.remains<1))|target.time_to_die<=20"] = {
	Type = "item",
	ID = 109217--[[Draenic Agility Potion]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and ((a.Hasted() and (not x.TalentStampedeEnabled or s.SpellCooldown(121818--[[Stampede]]) < (1 + x.Lag))) or x.TimeToDie <= 20)
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Concussive Shot"] = {
	ID = 5116--[[Concussive Shot]],
	CheckLast = function(z)
		return not x.Boss and s.Moving("target") and s.EnemyTargetingYou("target")
	end,
	FlashColor = "Red",
	EnemyTargetNeeded = true,
}

a.spells["Disengage"] = {
	ID = 781--[[Disengage]],
	CheckLast = function(z)
		return x.ActiveEnemy and s.MeleeDistance("target") and s.EnemyTargetingYou("target")
	end,
	FlashColor = "Red",
	NoGCD = true,
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
}

a.spells["Feign Death"] = {
	ID = 5384--[[Feign Death]],
	NotWhileMoving = true,
	CheckLast = function(z)
		return (s.HealthPercent("player") < 50 and s.EnemyTargetingYou("target")) or x.ThreatPercent > 80
	end,
	FlashColor = "Red",
	NoGCD = true,
}

a.spells["Master's Call"] = {
	ID = 53271--[[Master's Call]],
	Check = function(z)
		return x.PetAlive
	end,
	CheckLast = function(z)
		local runSpeed
		_, runSpeed = GetUnitSpeed("player")
		runSpeed = runSpeed / 7 * 100
		if runSpeed < 100 then
			return true
		end
		local eventIndex = C_LossOfControl.GetNumEvents()
		while (eventIndex > 0) do
			local locType, _, _, _, _, timeRemaining = C_LossOfControl.GetEventInfo(eventIndex)
			if locType == "ROOT" then
				return timeRemaining > 1.5
			end
			eventIndex = eventIndex - 1
		end
	end,
	NoRangeCheck = true,
	FlashBlink = true,
	FlashColor = "Aqua",
	NoGCD = true,
}

a.spells["Exhilaration"] = {
	ID = 109304--[[Exhilaration]],
	CheckLast = function(z)
		return a.HasTalent(109304--[[Exhilaration]]) and (s.HealthPercent("player") < 78 or (x.PetAlive and s.HealthPercent("pet") < 50))
	end,
	NoGCD = true,
	FlashColor = "Red",
}

a.spells["Counter Shot"] = {
	ID = 147362--[[Counter Shot]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["flask,type=greater_draenic_agility_flask"] = {
	Type = "item",
	ID = 109153--[[Greater Draenic Agility Flask]],
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss() and s.BuffDuration(156064--[[Greater Draenic Agility Flask]], "player", nil, false, false, true) < 300
	end,
	FlashColor = "Yellow",
}